<div align="left"><img src="https://github.com/yinsn/Lova/blob/develop/docs/images/lova.svg" width="400"/></div>

# Lova
[![Python](https://img.shields.io/badge/python3.8%7C3.9-red?logo=Python&logoColor=white)](https://www.python.org)
[![PyPI](https://img.shields.io/pypi/v/lova?color=green)](https://pypi.org/project/lova/)
[![GitHub license](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/yinsn/lova)

Lova (Long-term Value Algorithm) is a recommendation algorithm framework focused on long-term value matching.
